@@ -41,7 +41,11 @@ terminal_info_bar_init (TerminalInfoBar *bar)
 
 	priv = bar->priv = TERMINAL_INFO_BAR_GET_PRIVATE (bar);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+	priv->content_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+#else
 	priv->content_box = gtk_vbox_new (FALSE, 6);
+#endif
 	gtk_box_pack_start (GTK_BOX (gtk_info_bar_get_content_area (info_bar)),
 	                    priv->content_box, TRUE, TRUE, 0);
 }
@@ -113,7 +117,12 @@ terminal_info_bar_format_text (TerminalInfoBar *bar,
 
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+	gtk_label_set_yalign (GTK_LABEL (label), 0.0);
+#else
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
+#endif
 
 	gtk_box_pack_start (GTK_BOX (priv->content_box), label, FALSE, FALSE, 0);
 	gtk_widget_show_all (priv->content_box);
