@@ -343,15 +343,6 @@ terminal_screen_style_set (GtkWidget *widget,
 }
 
 #ifdef MATE_ENABLE_DEBUG
-static void
-size_request (GtkWidget *widget,
-              GtkRequisition *req)
-{
-	_terminal_debug_print (TERMINAL_DEBUG_GEOMETRY,
-	                       "[screen %p] size-request %d : %d\n",
-	                       widget, req->width, req->height);
-}
-
 static void
 size_allocate (GtkWidget *widget,
                GtkAllocation *allocation)
@@ -436,7 +427,6 @@ terminal_screen_init (TerminalScreen *screen)
 #ifdef MATE_ENABLE_DEBUG
 	_TERMINAL_DEBUG_IF (TERMINAL_DEBUG_GEOMETRY)
 	{
-		g_signal_connect_after (screen, "size-request", G_CALLBACK (size_request), NULL);
 		g_signal_connect_after (screen, "size-allocate", G_CALLBACK (size_allocate), NULL);
 	}
 #endif
@@ -628,7 +618,7 @@ terminal_screen_class_init (TerminalScreenClass *klass)
 		GError *error = NULL;
 
 		url_regexes[i] = g_regex_new (url_regex_patterns[i].pattern,
-		                              url_regex_patterns[i].flags | G_REGEX_OPTIMIZE,
+		                              url_regex_patterns[i].flags | G_REGEX_OPTIMIZE | G_REGEX_MULTILINE,
 		                              0, &error);
 		if (error)
 		{
@@ -647,7 +637,9 @@ terminal_screen_class_init (TerminalScreenClass *klass)
 	{
 		GError *error = NULL;
 
-		skey_regexes[i] = g_regex_new (skey_regex_patterns[i].pattern, G_REGEX_OPTIMIZE, 0, &error);
+		skey_regexes[i] = g_regex_new (skey_regex_patterns[i].pattern,
+		                               G_REGEX_OPTIMIZE | G_REGEX_MULTILINE,
+		                               0, &error);
 		if (error)
 		{
 			g_message ("%s", error->message);
@@ -952,7 +944,7 @@ terminal_screen_profile_notify_cb (TerminalProfile *profile,
 
 		/* madars.vitolins@gmail.com 24/07/2014 -
 		 * update terminal window config
-		 * with the flag of copy selection to cliboard or not. */
+		 * with the flag of copy selection to clipboard or not. */
 		terminal_window_update_copy_selection(screen, window);
 	}
 
